import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:pmd_lab/domain/models/card.dart';
import 'package:pmd_lab/presentation/details_page/details_page.dart';
part 'card.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        // colorScheme: ColorScheme.fromSeed(seedColor: Colors.black),                                                                                                                  colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
        useMaterial3: true,
      ),
      home: const MyHomePage(title: 'Flutter rocks!'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final Color _color = Colors.orangeAccent;

  @override
  void initState(){
    WidgetsBinding.instance.addPostFrameCallback( (_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text('Hello', style: Theme
            .of(context)
            .textTheme
            .bodyLarge,),
        backgroundColor: Colors.orangeAccent,
        duration: const Duration(seconds: 1),
      ));
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: _color,
        title: Text(widget.title),
      ),
      body: const Body(),
    );
  }
}

class Body extends StatelessWidget {
  const Body({super.key});

  @override
  Widget build(BuildContext context) {
    final data = [
      CardDate(
        'Какая-то новость',
        description: 'В данном блоке рекомендуем разместить краткую информацию',
        imgUrl:
        'https://universal.revengel.ru/assets/cache_image/images/services/3_731x487_1cb.png',
      ),
      CardDate(
        'Ещё какая-то новость',
        description: 'В данном блоке рекомендуем разместить краткую информацию',
        imgUrl:
        "https://universal.revengel.ru/assets/cache_image/images/services/2_731x487_1cb.png",
      ),
      CardDate(
        'Ещё одна новость',
        description: 'В данном блоке рекомендуем разместить краткую информацию',
        imgUrl:
        "https://universal.revengel.ru/assets/cache_image/images/services/1_731x487_1cb.png",
      )
    ];

    return Center(
      child: SingleChildScrollView(
        padding: const EdgeInsets.only(left: 20, right: 20, top: 20),
        child: Column(
            children: data.map((data) => _Card.fromData(
              data,
              onLike: (text, isLiked) => _showSnackBar(context, text, isLiked),
              onTap: () => _navToDetails(context, data),
            )).toList(),
        ),
      ),
    );
  }

  void _showSnackBar(BuildContext context, String title, bool isLiked){
    WidgetsBinding.instance.addPostFrameCallback( (_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
            'Article $title ${isLiked ? 'liked!' : 'disliked :('}',
            style: Theme.of(context).textTheme.bodyLarge,),
        backgroundColor: Colors.orangeAccent,
        duration: const Duration(seconds: 1),
      ));
    });
  }

  void _navToDetails(BuildContext context, CardDate data){
    Navigator.push(
      context,
      CupertinoPageRoute(builder: (context) => DetailsPage(data)),
    );
  }
}


